@@ -484,7 +484,7 @@ static cpl_error_code
   cpl_frame* ext_sky_frame=NULL;
   cpl_frame* ext_sky_frame_eso=NULL;
   cpl_frame* res_1D_sky_frame=NULL;
-
+  cpl_frame* sky_map_frm =NULL;
   int do_computemap=1;
   int use_model=0;
   int corr_tell=0;
@@ -623,8 +623,11 @@ static cpl_error_code
 
   /* remove crh on each obj or sky frame */
     xsh_msg("rec_prefix=%s",rec_prefix);
-    crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,instrument,rec_prefix,"OBJ");
-    crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par, instrument,rec_prefix,"SKY");
+    sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
+    crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,
+                    sky_map_frm,instrument, rec_prefix,"OBJ");
+    crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par,
+                    sky_map_frm, instrument,rec_prefix,"SKY");
 
 
     check(
