@@ -560,7 +560,7 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   cpl_frame * fluxcal_rect_2D_frame = NULL ;	
   cpl_frame * fluxframe = NULL;
   cpl_frame * uncalframe = NULL;
-
+  cpl_frame* sky_map_frm = NULL;
   cpl_frame* frm_atmext=NULL;
   int pre_overscan_corr=0;
   int generate_sdp_format=0;
@@ -655,7 +655,9 @@ static void xsh_scired_slit_nod( cpl_parameterlist* parameters,
   check(xsh_frameset_check_uniform_exptime(raws_ord_set,instrument));
   /* we fist flag CRH from each raw frame */
   cpl_frameset* crh_clean=NULL;
-  check(crh_clean = xsh_frameset_crh_single(raws_ord_set,crh_single_par,instrument, rec_prefix,"NOD"));
+  sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
+  check(crh_clean = xsh_frameset_crh_single(raws_ord_set, crh_single_par,
+                  sky_map_frm, instrument, rec_prefix, "NOD"));
 
   /* combine nod frames: AAA BBB BBB AAA AAAAA BBBBB BBBBB AAAAAA--> A B B A A B B A */
   check( raws_avg = xsh_nod_group_by_reloff( crh_clean,instrument,stack_par));
