@@ -481,7 +481,7 @@ static void xsh_scired_slit_offset( cpl_parameterlist* parameters,
   cpl_frame* res_1D_sky_frame=NULL;
   cpl_frame * fluxframe = NULL;
   cpl_frame * uncalframe = NULL;
-
+  cpl_frame* sky_map_frm = NULL;
   int pre_overscan_corr=0;
   int merge_par=0;
   xsh_interpolate_bp_param *ipol_bp=NULL;
@@ -593,8 +593,11 @@ static void xsh_scired_slit_offset( cpl_parameterlist* parameters,
 
 
   /* remove crh on each obj or sky frame */
-  crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,instrument,rec_prefix,"OBJ");
-  crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par, instrument,rec_prefix,"SKY");
+  sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
+  crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,
+                  sky_map_frm,instrument,rec_prefix,"OBJ");
+  crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par,
+                  sky_map_frm, instrument,rec_prefix,"SKY");
 
   check(
       sub_frameset = xsh_subtract_sky_offset( crh_clean_obj, crh_clean_sky, nb_sub_frames,instrument));
