@@ -433,10 +433,12 @@ static cpl_error_code
 xsh_scired_slit_stare(cpl_parameterlist* parameters,
 				  cpl_frameset* frameset)
 {
-   const char* recipe_tags[3] = {XSH_OBJECT_SLIT_STARE,
-                                 XSH_STD_TELL_SLIT_STARE,
-				                 XSH_STD_FLUX_SLIT_STARE};
-  int recipe_tags_size = 3;
+
+  const int recipe_tags_size = 4;
+  const char* recipe_tags[4] = {XSH_OBJECT_SLIT_STARE,
+                                               XSH_SKY_SLIT,
+                                               XSH_STD_TELL_SLIT_STARE,
+				               XSH_STD_FLUX_SLIT_STARE};
 
   /* Input frames */
   cpl_frameset *raws = NULL;
@@ -580,6 +582,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   cpl_frameset* crh_clean_lacosmic = NULL;
   cpl_frameset *sub_bias_set = NULL;
   cpl_frameset *sub_dark_set = NULL;
+  cpl_frame* sky_map_frm = NULL;
+  cpl_frame* sky_orders_chunks =NULL;
   int cut_uvb_spectrum=0;
 
   /**************************************************************************/
@@ -592,6 +596,7 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
 
 
 
+
   /*
   assure( instrument->mode == XSH_MODE_SLIT, CPL_ERROR_ILLEGAL_INPUT,
 	  "Instrument NOT in Slit Mode" ) ;
@@ -618,7 +623,8 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   check(xsh_slit_stare_get_calibs(calib,instrument, &spectralformat_frame,
                                   &master_bias,&master_dark,&master_flat,
                                   &order_tab_edges,&model_config_frame,
-                                  &wave_tab,&sky_list_frame,&qc_sky_frame,
+                                  &wave_tab,&sky_list_frame,&sky_orders_chunks,
+                                  &qc_sky_frame,
                                   &bpmap,&single_frame_sky_sub_tab_frame,
                                   &wavemap_frame,&slitmap_frame,RECIPE_ID,
 				  &recipe_use_model,pre_overscan_corr));
@@ -741,8 +747,9 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
   check( rec_prefix = xsh_set_recipe_file_prefix( raws,
     "xsh_scired_slit_stare"));
   sprintf(prefix,"%s_",rec_prefix);
-
-  crh_clean_lacosmic = xsh_frameset_crh_single(sub_dark_set, crh_single_par,instrument,rec_prefix,"OBJ");
+  sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
+  crh_clean_lacosmic = xsh_frameset_crh_single(sub_dark_set, crh_single_par,
+                  sky_map_frm, instrument, rec_prefix, "OBJ");
 
 
 
@@ -779,29 +786,38 @@ xsh_scired_slit_stare(cpl_parameterlist* parameters,
      xsh_pre_free(&pre_sci);
   }
 
-
-
-  /* In case CRH single or localize auto do preliminar sky subtraction */
+  /* In case CRH single or localize auto do preliminary sky subtraction */
   xsh_slit_stare_correct_crh_and_sky(loc_obj_par,crh_single_par,rectify_par,
                                      do_sub_sky,rec_prefix,rmbkg,
                                      order_tab_edges, slitmap_frame, 
                                      wavemap_frame,model_config_frame,
                                      single_frame_sky_sub_tab_frame,instrument,
-                                     sub_sky_nbkpts1, sky_par,
+                                     sub_sky_nbkpts1, sky_par,sky_list_frame,sky_orders_chunks,
                                      &sky_frame,&sky_frame_eso,&sky_frame_ima,
                                      wave_tab,disp_tab_frame,
                                      spectralformat_frame,nb_raw_frames,
                                      &loc_table_frame,&clean_frame,&clean_obj,0);
 
-
   /* now we divide by the flat for proper sky subtraction */
   check( div_frame = xsh_check_divide_flat( do_flatfield, clean_obj,
     master_flat, instrument, rec_prefix));
 
-  check( sub_sky2_frame = xsh_check_subtract_sky_single( do_sub_sky, div_frame,
-      order_tab_edges, slitmap_frame, wavemap_frame, loc_table_frame, NULL,
-      single_frame_sky_sub_tab_frame, instrument, sub_sky_nbkpts2, sky_par,
-      &sky_frame, &sky_frame_eso, &sky_frame_ima, rec_prefix,0));
+  check( sub_sky2_frame = xsh_check_subtract_sky_single( do_sub_sky,
+                                                         div_frame,
+                                                         order_tab_edges,
+                                                         slitmap_frame,
+                                                         wavemap_frame,
+                                                         loc_table_frame,
+                                                         single_frame_sky_sub_tab_frame,
+                                                         instrument,
+                                                         sub_sky_nbkpts2,
+                                                         sky_par,
+                                                         sky_list_frame,sky_orders_chunks,
+                                                         &sky_frame,
+                                                         &sky_frame_eso,
+                                                         &sky_frame_ima,
+                                                         rec_prefix,
+                                                         0));
 
   xsh_msg( "Prepare S2D products" ) ; 
   xsh_msg( "Rectify") ;
