@@ -537,6 +537,7 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   int use_model=0;
   cpl_frameset* crh_clean_obj = NULL;
   cpl_frameset* crh_clean_sky = NULL;
+  cpl_frame* sky_map_frm = NULL;
   int do_flatfield = 1;
   /**************************************************************************/
   /* DFS management */
@@ -682,6 +683,23 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   check(strcpy(rec_prefix,(const char*)prefix));
   XSH_FREE(prefix);
 
+  //check(object_frame=cpl_frameset_get_frame(raw_object,0));
+   if ( model_config_frame == NULL){
+     xsh_msg("RECIPE USE WAVE SOLUTION");
+     recipe_use_model = FALSE;
+     do_compute_map = TRUE;
+   }
+   else{
+     xsh_msg("RECIPE USE MODEL");
+     recipe_use_model = TRUE;
+   }
+
+  if ( do_compute_map && recipe_use_model==FALSE){
+     check( disp_tab_frame = xsh_find_disp_tab( calib, instrument));
+   }
+
+
+
   xsh_msg("cmap=%d wavemap=%p slitmap=%p",do_computemap,wavemap,slitmap);
   if( (do_computemap == 1) &&
       (wavemap ==NULL || slitmap ==NULL )
@@ -704,8 +722,11 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
   }
 
   /* remove crh on each obj or sky frame */
-  crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,instrument,rec_prefix,"OBJ");
-  crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par, instrument,rec_prefix,"SKY");
+  sky_map_frm = xsh_find_frame_with_tag(calib,XSH_SKY_MAP, instrument);
+  crh_clean_obj = xsh_frameset_crh_single(raw_object, crh_single_par,sky_map_frm,
+                  instrument,rec_prefix,"OBJ");
+  crh_clean_sky = xsh_frameset_crh_single(raw_sky, crh_single_par, sky_map_frm,
+                  instrument,rec_prefix,"SKY");
 
 
   /* For each pair, subtract OBJECT-SKY */
@@ -714,19 +735,6 @@ static void xsh_scired_ifu_offset( cpl_parameterlist* parameters,
 
 
 
-  //check(object_frame=cpl_frameset_get_frame(raw_object,0));
-  if ( model_config_frame == NULL){
-    xsh_msg("RECIPE USE WAVE SOLUTION");
-    recipe_use_model = FALSE;
-  }
-  else{
-    xsh_msg("RECIPE USE MODEL");
-    recipe_use_model = TRUE;
-  }
-
- if ( do_compute_map && recipe_use_model==FALSE){
-    check( disp_tab_frame = xsh_find_disp_tab( calib, instrument));
-  }
 
   /**************************************************************************/
   /* Check that SCI IFU frame and AFC corrected CFG are proper              */
