@@ -156,6 +156,118 @@ static cpl_error_code xsh_flag_ima_bad_pix(cpl_image** image, int* bppix,const i
 }
 
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief Allows the growing and shrinking of bad pixel masks. It can be used to
+  e.g. set pixels to bad if the pixel is surrounded by other bad pixels.
+  @param input_mask input mask
+  @param kernel_nx  size in x-direction of the filtering kernel
+  @param kernel_ny  size in y-direction of the filtering kernel
+  @param filter     filter modes as defined in cpl - see below
+  Supported modes:
+  CPL_FILTER_EROSION, CPL_FILTER_DILATION, CPL_FILTER_OPENING,
+  CPL_FILTER_CLOSING
+
+  The returned mask must be deallocated using cpl_mask_delete().
+  The algorithm assumes, that all pixels outside the mask are good, i.e. it
+  enlarges the mask by the kernel size and marks this border as good. It
+  applies on the enlarged mask the operation and extract the original-size
+  mask at the very end.
+ */
+/*----------------------------------------------------------------------------*/
+cpl_mask * xsh_bpm_filter(
+        const cpl_mask    *   input_mask,
+        cpl_size        kernel_nx,
+        cpl_size        kernel_ny,
+        cpl_filter_mode filter)
+{
+    cpl_mask * kernel = NULL;
+    cpl_mask * filtered_mask = NULL;
+    cpl_mask * expanded_mask = NULL;
+    cpl_mask * expanded_filtered_mask = NULL;
+
+    /* Check Entries */
+    cpl_ensure(input_mask != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(kernel_nx >= 1, CPL_ERROR_ILLEGAL_INPUT, NULL);
+    cpl_ensure(kernel_ny >= 1, CPL_ERROR_ILLEGAL_INPUT, NULL);
+    cpl_ensure(filter == CPL_FILTER_EROSION || filter == CPL_FILTER_DILATION ||
+            filter == CPL_FILTER_OPENING || filter == CPL_FILTER_CLOSING,
+            CPL_ERROR_ILLEGAL_INPUT, NULL);
+
+    /* Only odd-sized masks allowed */
+    cpl_ensure((kernel_nx&1) == 1, CPL_ERROR_ILLEGAL_INPUT, NULL);
+    cpl_ensure((kernel_ny&1) == 1, CPL_ERROR_ILLEGAL_INPUT, NULL);
+
+    kernel = cpl_mask_new(kernel_nx, kernel_ny);
+    cpl_mask_not(kernel); /* All values set to unity*/
+
+    /* Enlarge the original mask with the kernel size and assume that outside
+     * all pixels are good */
+    expanded_mask = cpl_mask_new(
+            cpl_mask_get_size_x(input_mask) + 2 * kernel_nx,
+            cpl_mask_get_size_y(input_mask) + 2 * kernel_ny);
+
+    cpl_mask_copy(expanded_mask, input_mask, kernel_nx + 1, kernel_ny +1 );
+
+    expanded_filtered_mask = cpl_mask_new(cpl_mask_get_size_x(expanded_mask),
+            cpl_mask_get_size_y(expanded_mask));
+
+    if(cpl_mask_filter(expanded_filtered_mask, expanded_mask, kernel, filter,
+                    CPL_BORDER_ZERO) != CPL_ERROR_NONE) {
+
+        cpl_mask_delete(kernel);
+        cpl_mask_delete(expanded_filtered_mask);
+        cpl_mask_delete(expanded_mask);
+        return NULL;
+    }
+
+    /* Extract the original mask from the expanded mask */
+    filtered_mask = cpl_mask_extract(expanded_filtered_mask,
+            kernel_nx+1, kernel_ny + 1,
+            cpl_mask_get_size_x(input_mask) + kernel_nx,
+            cpl_mask_get_size_y(input_mask) + kernel_ny);
+
+
+    /* Free memory */
+    cpl_mask_delete(kernel);
+    cpl_mask_delete(expanded_filtered_mask);
+    cpl_mask_delete(expanded_mask);
+
+    return filtered_mask;
+}
+
+
+/**
+ * Create the bad pixel map (cpl format) attached to the XSH format
+ * Bad Pixel Map image
+ *
+ * @param image the image on which attaches the cpl bpmap
+ * @param bpmap XSH format bad pixel map
+ * @param decode_bp bad pixel code to be rejected
+ */
+cpl_mask*
+xsh_qual_to_cpl_mask(cpl_image * qual, const int decode_bp) {
+  cpl_mask *mask = NULL;
+
+  assure( qual != NULL, CPL_ERROR_NULL_INPUT,
+      "QUAL input is NULL pointer" );
+  cpl_size nx=cpl_image_get_size_x(qual);
+  cpl_size ny=cpl_image_get_size_y(qual);
+
+  mask=cpl_mask_new(nx,ny);
+  int* pqual=cpl_image_get_data_int(qual);
+  cpl_binary* pmask=cpl_mask_get_data(mask);
+  int size=nx*ny;
+  for(int i=0;i<size;i++){
+      if( (pqual[i] & decode_bp) >0 ) {
+          /* if pixel is bad flag it in table */
+          pmask[i]=CPL_BINARY_1;
+      }
+  }
+  cleanup:
+  return mask;
+}
+
 
 /** 
  * Create the bad pixel map (cpl format) attached to the XSH format
