@@ -80,6 +80,9 @@
 #define QFLAG_SATURATED_DATA 0x100000 /* 2e20 */
 #define QFLAG_NEGATIVE_DATA 0x200000 /* 2e21 */
 #define QFLAG_INTERPOL_FLUX 0x400000 /* 2e22 */
+#define QFLAG_SKY_MODEL_BAD_FIT 0x800000 /* 2e23 */
+#define QFLAG_SKY_MODEL_BAD_PIX 0x1000000 /* 2e24 */
+
 #define QFLAG_OUTSIDE_DATA_RANGE 0x40000000 /* 2e30 */
     /*} PIXEL_QUALITY_FLAG ; */
 
@@ -93,11 +96,18 @@ void xsh_bpmap_set_bad_pixel( cpl_image * bpmap, int ix, int iy,
 			      int flag ) ;
 void xsh_bpmap_mask_bad_pixel(cpl_image * bpmap, cpl_mask* mask,
   int flag ) ;
+cpl_mask* xsh_qual_to_cpl_mask(cpl_image * qual, const int decode_bp);
 
 cpl_frame*
 xsh_badpixelmap_crea_master_from_bpmap(cpl_frame* bpmap, xsh_instrument* inst);
 
 cpl_image * xsh_bpmap_collapse_bpmap_create( cpl_imagelist *list,const int decode_bp ) ;
+cpl_mask * xsh_bpm_filter(
+        const cpl_mask    *   input_mask,
+        cpl_size        kernel_nx,
+        cpl_size        kernel_ny,
+        cpl_filter_mode filter);
+
 int xsh_bpmap_count( cpl_image *bpmap, int nx, int ny ) ;
 void xsh_bpmap_collapse_median(cpl_image* median, cpl_imagelist *list,
 			       cpl_mask *mask ) ;
