@@ -138,10 +138,7 @@ cpl_frameset * xsh_subtract_on_off( cpl_frameset *set,
 
   for( i = 0 ; i<nframes ; i+=2 ) {
     const char *filename = NULL;
-
-    if ( i == 0 )
-      currOn = cpl_frameset_get_first (set);
-    else currOn = cpl_frameset_get_next (set);
+    currOn = cpl_frameset_get_frame(set,i);
     assure( currOn != NULL, cpl_error_get_code(),
 	    "Cant get frame of frameset" ) ;
     filename = cpl_frame_get_filename (currOn);
@@ -149,7 +146,7 @@ cpl_frameset * xsh_subtract_on_off( cpl_frameset *set,
     check_msg( preOn = xsh_pre_load( currOn, instrument ),
 	       "Cant load PRE ON" ) ;
 
-    currOff = cpl_frameset_get_next (set);
+    currOff = cpl_frameset_get_frame (set,i+1);
     assure( currOff != NULL, cpl_error_get_code(),
 	    "Cant get frame of frameset" ) ;
     filename = cpl_frame_get_filename (currOff);
@@ -241,8 +238,8 @@ xsh_linear_group_by_exptime (cpl_frameset * raws, xsh_instrument* instrument,
     cpl_propertylist *header;
     current = NULL ;
 
-    if ( i == 0 ) current = cpl_frameset_get_frame (raws,0);
-    else current = cpl_frameset_get_next (raws) ;
+    current = cpl_frameset_get_frame (raws,i);
+
     assure( current != NULL, CPL_ERROR_ILLEGAL_INPUT,
 	    "Cant get Frame #%d from frameset", i ) ;
     /* Load propertylist of current frame */
@@ -641,7 +638,7 @@ xsh_compute_linearity (cpl_frameset * medSet, xsh_instrument *instrument,
       assure( bpmap_header != NULL, cpl_error_get_code(),
 	      "Cant get bpmap header of frame %d", i ) ;
     }
-    current = cpl_frameset_get_next( medSet ) ;
+    current = cpl_frameset_get_frame( medSet,i+1 ) ;
     xsh_msg_dbg_low( "-- Next Frame" ) ;
   }
 
@@ -661,38 +658,6 @@ xsh_compute_linearity (cpl_frameset * medSet, xsh_instrument *instrument,
 			      resBpmap, decode_bp ) ;
   }
 
-#if defined(JUST_FOR_TEST)
-  // Just a test
-  {
-    int ll = 0;
-    cpl_vector * pixvect = NULL;
-    cpl_vector * temps = NULL;
-    cpl_polynomial *poly = NULL;
-
-
-    pixvect = cpl_vector_new( nframes ) ;
-    temps = cpl_vector_new( nframes ) ;
-
-    xsh_msg( "===== Fit polynome (1) sur valeurs moyennes des med frames" ) ;
-    for( ll = 0 ; ll < nframes ; ll++ ) {
-      cpl_image *cur = NULL ;
-      cur = cpl_imagelist_get( medList, ll ) ;
-      xsh_msg( "       #%d: mean=%lf, DIT=%lf", ll, cpl_image_get_mean( cur ),
-	       *(Dit+ll) ) ;
-      cpl_vector_set( pixvect, ll, cpl_image_get_mean( cur ) ) ;
-      cpl_vector_set( temps, ll, *(Dit+ll) ) ;
-    }
-    poly = xsh_polynomial_fit_1d_create( temps, pixvect,
-					 LINEAR_POLYNOMIAL_DEGREE,
-					 NULL ) ;
-    cpl_polynomial_dump( poly, stderr ) ;
-    xsh_msg( "===== Ca ne ressemble en rien a ce qu'on obtient dans le" ) ;
-    xsh_msg( "      fit general. Bizarre n'est-il pas ?" ) ;
-    for ( ll = 0 ; ll<=LINEAR_POLYNOMIAL_DEGREE ; ll++ )
-      xsh_msg( ">>>>> %d : %lf\n", ll,
-	       cpl_polynomial_get_coeff( poly, &ll ) ) ;
-  }
-#endif
 #if defined(USE_CPL_POLYNOMIAL)
   /* CPL imagelist Polynomial fit */
   xsh_msg( "Now fit polynomial - CPL version" ) ;
