@@ -249,6 +249,11 @@
 #define XSH_SKY_SUB_BKPTS_VIS "SKY_SUB_BKPTS_VIS"
 #define XSH_SKY_SUB_BKPTS_NIR "SKY_SUB_BKPTS_NIR"
 
+#define XSH_SKY_ORDERS_CHUNKS "SKY_ORDERS_CHUNKS"
+#define XSH_SKY_ORDERS_CHUNKS_UVB "SKY_ORDERS_CHUNKS_UVB"
+#define XSH_SKY_ORDERS_CHUNKS_VIS "SKY_ORDERS_CHUNKS_VIS"
+#define XSH_SKY_ORDERS_CHUNKS_NIR "SKY_ORDERS_CHUNKS_NIR"
+
 #define XSH_GAIN "GAIN_INFO"
 #define XSH_GAIN_UVB "GAIN_INFO_UVB"
 #define XSH_GAIN_VIS "GAIN_INFO_VIS"
@@ -270,7 +275,10 @@
 #define XSH_EXTCOEFF_TAB_VIS "EXTCOEFF_TABLE_VIS"
 #define XSH_EXTCOEFF_TAB_NIR "EXTCOEFF_TABLE_NIR"
 
-
+#define XSH_SKY_MAP     "SKY_MAP"
+#define XSH_SKY_MAP_UVB "SKY_MAP_UVB"
+#define XSH_SKY_MAP_VIS "SKY_MAP_VIS"
+#define XSH_SKY_MAP_NIR "SKY_MAP_NIR"
 
 #define XSH_CPIX_MAP     "CPIX_MAP"
 #define XSH_CPIX_MAP_UVB "CPIX_MAP_UVB"
@@ -1432,7 +1440,9 @@
 			   XSH_CMP_TAG_ARM( tag, XSH_THEO_TAB_MULT) ||	\
 			   XSH_CMP_TAG_ARM( tag, XSH_THEO_TAB_IFU) ||	\
 			   XSH_CMP_TAG_ARM( tag, XSH_WAVE_MAP) ||	\
+			   XSH_CMP_TAG_ARM( tag, XSH_SKY_MAP) ||  \
 			   XSH_CMP_TAG_ARM( tag, XSH_SKY_SUB_BKPTS) ||	\
+			   XSH_CMP_TAG_ARM( tag, XSH_SKY_ORDERS_CHUNKS) ||  \
 		           (strcmp(tag,XSH_SPECTRAL_FORMAT_JH_NIR) == 0) || \
 			   XSH_CMP_TAG_ARM( tag, XSH_SPECTRAL_FORMAT) || \
 			   XSH_CMP_TAG_ARM( tag, XSH_GUESS_LINES_POS) || \
