@@ -407,6 +407,8 @@ xsh_subtract_sky_single (cpl_frame * sci_frame,
 			 cpl_frame * slitmap_frame,
 			 cpl_frame * wavemap_frame,
 			 cpl_frame * locTable_frame,
+			 cpl_frame* ref_sky_list,
+			 cpl_frame* sky_orders_chunks,
 			 cpl_frame* usr_defined_break_points_frame,
 			 xsh_instrument * instrument,
 			 int nbkpts,
@@ -471,7 +473,7 @@ cpl_frame * xsh_abs_remove_crh_single( cpl_frame *sci_frame,
 
 cpl_frame * 
 xsh_remove_crh_single( cpl_frame * sci_frame,
-		       xsh_instrument * instrument, 
+		       xsh_instrument * instrument, cpl_mask* sky_map,
 		       xsh_remove_crh_single_param * single_par,
 		       const char * name );
 
