@@ -108,16 +108,29 @@ xsh_extract_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
   xsh_msg_dbg_medium( "Parameters");
   xsh_msg_dbg_medium( "  method %s", EXTRACT_METHOD_PRINT(extract_par->method));
 
+  /* Load rectified table */
+  check( rec_list = xsh_rec_list_load( rec_frame, instrument));
+  check( slit_step = xsh_pfits_get_rectify_bin_space( rec_list->header));
+
   if (extract_par->method == NOD_METHOD) {
+      double nod_throw=0;
+
     name = cpl_frame_get_filename(rec_frame);
     plist = cpl_propertylist_load(name, 0);
     slit_ext_min = xsh_pfits_get_extract_slit_min(plist);
     slit_ext_max = xsh_pfits_get_extract_slit_max(plist) - 2;
+    nod_throw = xsh_pfits_get_nodthrow(plist);
+
+    //xsh_msg("before slit min: %g max: %g",slit_ext_min,slit_ext_max);
+    int nslit = xsh_rec_list_get_nslit(rec_list, 0);
+    int hslit = round(0.5 * nod_throw / slit_step);
+    slit_ext_max = nslit/2 + hslit;
+    slit_ext_min = nslit/2 - hslit;
+
+    //xsh_msg("after slit min: %g max: %g",slit_ext_min,slit_ext_max);
     xsh_free_propertylist(&plist);
   }
-  /* Load rectified table */
-  check( rec_list = xsh_rec_list_load( rec_frame, instrument));
-  check( slit_step = xsh_pfits_get_rectify_bin_space( rec_list->header));
+
 
   /* Load localization table */
   if ((extract_par->method != FULL_METHOD)
@@ -534,17 +547,25 @@ xsh_extract_clean_with_tag(cpl_frame * rec_frame, cpl_frame* loc_frame,
   xsh_msg_dbg_medium( "Parameters");
   xsh_msg_dbg_medium( "  method %s", EXTRACT_METHOD_PRINT(extract_par->method));
 
+  /* Load rectified table */
+  check( rec_list = xsh_rec_list_load( rec_frame, instrument));
+  check( slit_step = xsh_pfits_get_rectify_bin_space( rec_list->header));
   if (extract_par->method == NOD_METHOD) {
     name = cpl_frame_get_filename(rec_frame);
     plist = cpl_propertylist_load(name, 0);
     slit_ext_min = xsh_pfits_get_extract_slit_min(plist);
     slit_ext_max = xsh_pfits_get_extract_slit_max(plist) - 2;
+    double nod_throw = xsh_pfits_get_nodthrow(plist);
+    //xsh_msg("before slit min: %g max: %g",slit_ext_min,slit_ext_max);
+    int nslit = xsh_rec_list_get_nslit(rec_list, 0);
+    int hslit = round(0.5 * nod_throw / slit_step);
+    slit_ext_max = nslit/2 + hslit;
+    slit_ext_min = nslit/2 - hslit;
+    //xsh_msg("after slit min: %g max: %g",slit_ext_min,slit_ext_max);
     xsh_free_propertylist(&plist);
   }
 
-  /* Load rectified table */
-  check( rec_list = xsh_rec_list_load( rec_frame, instrument));
-  check( slit_step = xsh_pfits_get_rectify_bin_space( rec_list->header));
+
 
   /* Load localization table */
   if ((extract_par->method != FULL_METHOD)
