@@ -104,7 +104,32 @@ static void xsh_merge_point( double flux_a, double weight_a,
   cleanup:
     return;
 }
+static void
+xsh_spectrum_clean(xsh_spectrum *spectrum,const int decode_bp){
+    double *spectrum_flux = NULL;
+     double *spectrum_errs = NULL;
+     int *spectrum_qual = NULL;
 
+     spectrum_flux = xsh_spectrum_get_flux( spectrum);
+     spectrum_errs = xsh_spectrum_get_errs( spectrum);
+     spectrum_qual = xsh_spectrum_get_qual( spectrum);
+
+     cpl_mask* mask = xsh_qual_to_cpl_mask(spectrum->qual,decode_bp);
+
+     cpl_mask * filtered = xsh_bpm_filter(mask,5,5,CPL_FILTER_CLOSING);
+     xsh_free_mask(&mask);
+     cpl_image_save(spectrum->flux, "before.fits", CPL_TYPE_FLOAT, NULL, CPL_IO_CREATE);
+     cpl_image_reject_from_mask(spectrum->flux,filtered);
+
+     cpl_image_reject_from_mask(spectrum->errs,filtered);
+     cpl_detector_interpolate_rejected(spectrum->flux);
+     cpl_detector_interpolate_rejected(spectrum->errs);
+     cpl_image_save(spectrum->flux, "after.fits", CPL_TYPE_FLOAT, NULL, CPL_IO_CREATE);
+     xsh_free_mask(&filtered);
+
+     return;
+
+}
 /*****************************************************************************/
 /** 
   @brief 
@@ -358,6 +383,8 @@ static cpl_frame * xsh_merge_ord_with_tag(cpl_frame *rec_frame,
 
   const char* bunit = xsh_pfits_get_bunit(spectrum->flux_header);
   xsh_pfits_set_bunit(spectrum->errs_header, bunit);
+  /* AMO to verify quality of extraction */
+  //xsh_spectrum_clean(spectrum,decode_bp);
 
   check( res_frame = xsh_spectrum_save(spectrum, spectrum_name,tag));
   check( cpl_frame_set_tag( res_frame, tag));
