@@ -108,6 +108,9 @@
 #define XSH_QC_CRH_NUMBER_MEAN "ESO QC NCRH AVG"
 #define XSH_QC_CRH_NUMBER_MEAN_C "Average number of cosmic ray hits per frame"
 
+#define XSH_QC_CRH_NUMBER_TOT "ESO QC NCRH TOT"
+#define XSH_QC_CRH_NUMBER_TOT_C "Total number of cosmic ray hits on frames"
+
 #define XSH_QC_MASTER_DARK_MEDIAN  "ESO QC MDARKMED"
 #define XSH_QC_MASTER_DARK_MEDIAN_C  "Median value of the master DARK."
 
