@@ -258,10 +258,10 @@ xsh_rec_list_rectify( xsh_rec_list *rec_list, int iorder, int irec,
         /* Now propagate flags */
         int qual_val = 0;
         for(j=yfirst;j<ylast-1;j++) {
-           j_nx=j*nx;
-           for(i=xfirst;i<xlast-1;i++) {
-	     qual_val |= qual[j_nx+i];         //UMR
-          }
+            j_nx=j*nx;
+            for(i=xfirst;i<xlast-1;i++) {
+                qual_val |= qual[j_nx+i];         //UMR
+            }
         }
 
         /* Save the interpolated values */
@@ -1127,6 +1127,18 @@ xsh_rectify_orders( cpl_frame *sci_frame,
     rec_max_index = rec_list->size-1;
   }
 
+  /* AMO added to make sure bad pixels are flagged before re-sampling */
+
+    //xsh_msg("ok1");
+    //int decode_bp=2147483647;
+    int decode_bp=instrument->decode_bp;
+    cpl_mask* mask = xsh_qual_to_cpl_mask(pre_sci->qual,decode_bp);
+    cpl_image_reject_from_mask(pre_sci->data,mask);
+    //cpl_detector_interpolate_rejected(pre_sci->data);
+    xsh_free_mask(&mask);
+
+
+
   for( i = rec_min_index; i <= rec_max_index; i++ ) {
     double lambda_min, lambda_max ;
     double n;
