@@ -99,7 +99,7 @@ cpl_frame * xsh_abs_remove_crh_single( cpl_frame *sci_frame,
   }
   else{
     check( abs_frame = xsh_frame_abs( sci_frame, instrument, &sign_frame));
-    check( rmcrh_frame = xsh_remove_crh_single( abs_frame, instrument,
+    check( rmcrh_frame = xsh_remove_crh_single( abs_frame, instrument,NULL,
       single_par, res_tag));
     check( result_frame = xsh_frame_mult(  rmcrh_frame, instrument, sign_frame));
   }
@@ -132,7 +132,8 @@ cpl_frame * xsh_abs_remove_crh_single( cpl_frame *sci_frame,
 */
 /*****************************************************************************/
 cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
-    xsh_instrument * instrument, xsh_remove_crh_single_param * single_par,
+    xsh_instrument * instrument, cpl_mask* sky_map,
+    xsh_remove_crh_single_param * single_par,
     const char * res_tag) {
   int i, j,k,l,m;
   double sigma_lim, f_lim;
@@ -165,6 +166,7 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
   float* sci_data = NULL;
   float* err_data = NULL;
   int* qua_data = NULL;
+  int* msk_data = NULL;
 
   float* two_sub_sample_data = NULL;
   float* laplacian_data = NULL;
@@ -192,7 +194,7 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
   int nx = 0;
   int ny = 0;
   int j_nx=0;
- 
+
   /* Check parameters */XSH_ASSURE_NOT_NULL_MSG( in_sci_frame,"Null input science frame" );
   XSH_ASSURE_NOT_NULL_MSG( single_par,"Null input parameters" );
   XSH_ASSURE_NOT_NULL_MSG( instrument,"Null instrument setting" );
@@ -210,6 +212,13 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
   check( sci_copy = cpl_image_duplicate( sci_image));
   check( err_image = xsh_pre_get_errs( sci_pre));
   check( qua_image = xsh_pre_get_qual( sci_pre));
+
+  if (sky_map != NULL) {
+     cpl_image_reject_from_mask(sci_copy,sky_map);
+     msk_data = cpl_mask_get_data( sky_map);
+  }
+
+
   nx = sci_pre->nx;
   ny = sci_pre->ny;
 
@@ -429,6 +438,13 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
       j_nx = j*nx;
       for (i = 0; i < nx - 1 ; i++) {
          int  i_plus_j_nx = i + j_nx;
+         if ( (msk_data != NULL)  && (msk_data[i + j_nx] != CPL_BINARY_1) ) {
+             /* if the pixel was already flagged in input sky map
+              * does not search for CRH
+              */
+             //xsh_msg("found a bad pixel at j=%d i=%d",j,i);
+
+         } else {
           if ( s_data[i_plus_j_nx] > sigma_lim ) {
               if ( r_data[i_plus_j_nx] > f_lim ) {
 
@@ -478,6 +494,7 @@ cpl_frame * xsh_remove_crh_single(cpl_frame * in_sci_frame,
 
               }/* end check on 2nd threshold */
           } /* end check on 1st threshold */
+         }/* end check if given point should not be checked as flagged in map */
       } /* end loop over image columns */
     } /* end loop over image rows */
 
