@@ -390,7 +390,7 @@ cpl_frameset* xsh_nod_group_by_reloff2( cpl_frameset *ord_set,xsh_instrument *in
   const char *type= NULL;
 
   nraw=cpl_frameset_get_size(ord_set);
-  cpl_frameset_dump(ord_set,stdout);
+  //cpl_frameset_dump(ord_set,stdout);
 
   check( result=cpl_frameset_new());
 
@@ -1603,6 +1603,8 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
                           int pscan)
 {
 
+    cpl_boolean mode_phys;
+    mode_phys=xsh_mode_is_physmod(calib,inst);
     check(*spectral_format = xsh_find_spectral_format( calib, inst));
 
     XSH_ASSURE_NOT_NULL_MSG(*spectral_format,"Null input spectral format frame");
@@ -1685,13 +1687,6 @@ xsh_ifu_stare_get_calibs(cpl_frameset* calib,
 
 }
 
-
-
-
-
-
-
-
 cpl_error_code
 xsh_slit_stare_get_calibs(cpl_frameset* calib,
                           xsh_instrument* instrument,
@@ -1703,6 +1698,7 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
                           cpl_frame** model_cfg,
                           cpl_frame** wave_tab,
                           cpl_frame** sky_list,
+                          cpl_frame** sky_orders_chunks,
                           cpl_frame** qc_sky,
                           cpl_frame** bpmap,
                           cpl_frame** sframe_sky_sub_tab,
@@ -1772,10 +1768,10 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
       check( *wave_tab = xsh_find_wave_tab( calib, instrument));
       *recipe_use_model = FALSE;
    }
-
+   check(*sky_list = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
+                                              instrument));
    if ( *model_cfg != NULL){
-      check(*sky_list = xsh_find_frame_with_tag( calib, XSH_SKY_LINE_LIST,
-                                                 instrument));
+
       if ( *sky_list != NULL){
          /* we compute unbinned THE map to easier plots from QC garching */
          check(*qc_sky=xsh_util_physmod_model_THE_create(*model_cfg,instrument,
@@ -1792,7 +1788,7 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
       xsh_msg_warning("Data reduction with user defined break points number from file %s",
                       cpl_frame_get_filename(*sframe_sky_sub_tab));
    }
-
+   *sky_orders_chunks = xsh_find_frame_with_tag(calib,XSH_SKY_ORDERS_CHUNKS, instrument);
 
    check(*wmap = xsh_find_frame_with_tag(calib,XSH_WAVE_MAP,instrument));
    check(*smap = xsh_find_frame_with_tag(calib,XSH_SLIT_MAP,instrument));
@@ -1961,6 +1957,38 @@ xsh_slit_offset_get_params(cpl_parameterlist* parameters,
 
 }
 
+/*---------------------------------------------------------------------------*/
+
+/**
+  @brief correct CRH and sky lines (1st iteration)
+  @param[in] loc_obj_par parameters to localise the object
+  @param[in] crh_single_par parameters to do CRH rejection  TO BE REMOVED
+  @param[in] rectify_par parameters to do order rectification
+  @param[in] do_sub_sky is sky subtraction to be done? 1/0: yes/no
+  @param[in] rec_prefix recipe id
+  @param[in] rmbkg input frame (inter-order background subtracted)
+  @param[in] order_tab_edges order edges table
+  @param[in] slitmap slitmap frame
+  @param[in] wavemap wavemap frame
+  @param[in] model_config model configuration frame
+  @param[in] single_frame_sky_sub_tab reference frame with sky line positions
+  @param[in] instrument structure with information on the instrument (arm)
+  @param[in] sub_sky_nbkpts1 number of sky subtraction points (1st iteration)
+  @param[in] sky_par sky subtraction parameters
+  @param[out] sky output sky frame (DRL format)
+  @param[out] sky_eso output sky frame (ESO format)
+  @param[out] sky_ima output sky image used for QC    (NEEDED??)
+  @param[in] wave_tab wavelength table (used during order rectification)
+  @param[in] disp_tab wavelength table (used during rectif to compute Jakobian)
+  @param[in] spectral_format input spectral format table (used during rectification)
+  @param[in] nb_raw_frames number of input fraw frames (used to make a check)
+  @param[in] loc_table computed object localisation table
+  @param[out] clean sky subtracted frame (after 1st iteration)
+  @param[out] clean_obj input object frame (cleaned by CRH. Now same as rmbkg. NOT NEEDED)
+  @param[out] clean_tmp Switch to erase temporary products
+
+ */
+
 
 cpl_error_code
 xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
@@ -1977,6 +2005,8 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
                                    xsh_instrument* instrument,
                                    int sub_sky_nbkpts1, 
                                    xsh_subtract_sky_single_param* sky_par,
+                                   cpl_frame* ref_sky_list,
+                                   cpl_frame* sky_orders_chunks,
                                    cpl_frame** sky,
                                    cpl_frame** sky_eso,
                                    cpl_frame** sky_ima,
@@ -1989,99 +2019,96 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
                                    cpl_frame** clean_obj,const int clean_tmp)
 {
 
-  char sky_tag[256];
-  char sky_name[256];
-  char rec_name[256];
-  cpl_frame * sub_sky = NULL ; /**< Output of xsh_subtract_sky_single */
-  cpl_frame * rect = NULL ; /**< Output of xsh_rectfiy */
+    char sky_tag[256];
+    char sky_name[256];
+    char rec_name[256];
+    cpl_frame * sub_sky = NULL ; /**< Output of xsh_subtract_sky_single */
+    cpl_frame * rect = NULL ;    /**< Output of xsh_rectfiy */
 
-  if( (loc_obj_par->method != LOC_MANUAL_METHOD) || 
-         (nb_raw_frames == 1 && crh_single_par->nb_iter > 0)){
-     xsh_msg("Preliminary sky subtraction for CRH single or automatic localization");
-     xsh_msg("Sky will be put back later");
+    if( (loc_obj_par->method != LOC_MANUAL_METHOD) ){
+                  //  || (nb_raw_frames == 1 && crh_single_par->nb_iter > 0)){
 
-    sprintf(sky_tag,"%s_TMPSKY",rec_prefix);
-    sprintf(sky_name,"%s.fits",sky_tag);
+        xsh_msg("Preliminary sky subtraction for CRH single or automatic localization");
+        xsh_msg("Sky will be put back later");
 
-    if(do_sub_sky) {
-      check( sub_sky = xsh_check_subtract_sky_single( CPL_TRUE, rmbkg, 
-							    order_tab_edges, 
-                                                            slitmap, 
-                                                            wavemap, 
-                                                            NULL, NULL,
-							    single_frame_sky_sub_tab, 
-                                                            instrument, 
-                                                            sub_sky_nbkpts1, 
-                                                            sky_par,
-							    sky, 
-                                                            sky_eso, 
-                                                            sky_ima, 
-						      sky_tag,clean_tmp));
-      xsh_add_temporary_file(sky_name);
-   
-    } else {
-      sub_sky = cpl_frame_duplicate(rmbkg);
-      xsh_add_temporary_file(sky_name);
+        sprintf(sky_tag,"%s_TMPSKY",rec_prefix);
+        sprintf(sky_name,"%s.fits",sky_tag);
+
+        if(do_sub_sky) {
+            /* TODO AMO: aded frame for DEBUG */
+            xsh_msg("rmbkg=%p",rmbkg);
+            check(xsh_frame_image_save(rmbkg,"rmbkg.fits"));
+            xsh_msg("instrument=%p",instrument);
+            check( sub_sky = xsh_check_subtract_sky_single( CPL_TRUE, rmbkg,
+                            order_tab_edges, slitmap, wavemap, NULL,
+                            single_frame_sky_sub_tab, instrument, sub_sky_nbkpts1,
+                            sky_par,ref_sky_list, sky_orders_chunks,sky, sky_eso, sky_ima, sky_tag,clean_tmp));
+            xsh_add_temporary_file(sky_name);
+
+            /* TODO AMO: aded frame for DEBUG */
+            xsh_frame_image_save(sub_sky,"sub_sky.fits");
+            //exit(0);
+
+        } else {
+            sub_sky = cpl_frame_duplicate(rmbkg);
+            xsh_add_temporary_file(sky_name);
+        }
+
+        if( loc_obj_par->method != LOC_MANUAL_METHOD){
+            xsh_msg("Localize auto");
+            sprintf(rec_name,"%s_%s_%s.fits",
+                    rec_prefix,XSH_ORDER2D,
+                    xsh_instrument_arm_tostring(instrument));
+
+            check( rect = xsh_rectify( sub_sky, order_tab_edges,
+                            wave_tab, model_config,
+                            instrument, rectify_par,
+                            spectral_format, disp_tab,
+                            rec_name, NULL, NULL,rec_prefix));
+
+            check( *loc_table = xsh_localize_obj( rect, NULL, instrument,
+                            loc_obj_par, NULL, NULL));
+            xsh_free_frame( &rect);
+        }
+        else{
+            check( *loc_table = xsh_localize_obj( NULL, NULL,
+                            instrument, loc_obj_par, NULL, NULL));
+        }
+
+        /* NB Remove COSMICS single temporarily dis-activated for Daniel
+          check( *clean = xsh_check_remove_crh_single( nb_raw_frames, sub_sky,
+                          crh_single_par, instrument, rec_prefix));
+         */
+        *clean = cpl_frame_duplicate(sub_sky);
+
+        if(clean_tmp) {
+            xsh_add_temporary_file(cpl_frame_get_filename(*clean));
+        }
+        if(do_sub_sky) {
+            check( *clean_obj = xsh_add_sky_model( *clean, *sky_ima,
+                            instrument, rec_prefix));
+        } else {
+            *clean_obj=cpl_frame_duplicate(*clean);
+        }
+
+        xsh_free_frame( &sub_sky);
+        xsh_free_frame( sky);
+        xsh_free_frame( sky_eso);
+        xsh_free_frame( sky_ima);
     }
-     if( loc_obj_par->method != LOC_MANUAL_METHOD){
-        xsh_msg("Localize auto");
-        sprintf(rec_name,"%s_%s_%s.fits",
-		rec_prefix,XSH_ORDER2D,
-                xsh_instrument_arm_tostring(instrument));
-
-        /* rectify */ 
-  
-        check( rect = xsh_rectify( sub_sky, order_tab_edges,
-                                         wave_tab, model_config, 
-					 instrument, rectify_par,
-                                         spectral_format, disp_tab, 
-                                         rec_name, NULL, NULL,rec_prefix));
-
-        /* localize */
-        check( *loc_table = xsh_localize_obj( rect, NULL, instrument,
-                                                   loc_obj_par, NULL, NULL));
-      xsh_free_frame( &rect);
-     }
-     else{
-       check( *loc_table = xsh_localize_obj( NULL, NULL,
-      instrument, loc_obj_par, NULL, NULL));
-     }
-
-    /* NB Remove COSMICS single temporarily dis-activated for Daniel
-    check( *clean = xsh_check_remove_crh_single( nb_raw_frames, sub_sky,
-      crh_single_par, instrument, rec_prefix));
-      */
-     *clean = cpl_frame_duplicate(sub_sky);
-    
-    if(clean_tmp) {
-      xsh_add_temporary_file(cpl_frame_get_filename(*clean));
+    else {
+        /* LOcalize manual && no CRH SINGLE */
+        check( *clean_obj=cpl_frame_duplicate(rmbkg));
+        check( *loc_table = xsh_localize_obj( NULL, NULL,
+                        instrument, loc_obj_par, NULL, NULL));
     }
-    if(do_sub_sky) {
-      check( *clean_obj = xsh_add_sky_model( *clean, *sky_ima,
-					    instrument, rec_prefix));
-    } else {
-      *clean_obj=cpl_frame_duplicate(*clean);
-    }
-    
-    xsh_free_frame( &sub_sky);
-    xsh_free_frame( sky);
-    xsh_free_frame( sky_eso);
-    xsh_free_frame( sky_ima);
-  } 
-  else {
-     /* LOcalize manual && no CRH SINGLE */
-     check( *clean_obj=cpl_frame_duplicate(rmbkg));
-     check( *loc_table = xsh_localize_obj( NULL, NULL,
-      instrument, loc_obj_par, NULL, NULL));
-  }
 
+    cleanup:
 
- cleanup:
+    xsh_free_frame(&sub_sky) ;
+    xsh_free_frame(&rect) ;
 
-   xsh_free_frame(&sub_sky) ;
-   xsh_free_frame(&rect) ;
-
-   return cpl_error_get_code();
+    return cpl_error_get_code();
 
 }
 
@@ -2664,7 +2691,9 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
 */
 /*****************************************************************************/
 cpl_frameset*
-xsh_frameset_crh_single(cpl_frameset* raws,xsh_remove_crh_single_param * crh_single_par,
+xsh_frameset_crh_single(cpl_frameset* raws,
+                        xsh_remove_crh_single_param * crh_single_par,
+                        cpl_frame* sky_map_frm,
     xsh_instrument* instrument,const char* prefix,const char* spec)
 {
 /* remove crh on frame */
@@ -2675,8 +2704,15 @@ xsh_frameset_crh_single(cpl_frameset* raws,xsh_remove_crh_single_param * crh_sin
  char ftag[256];
  char fname[256];
  char  arm_str[16] ;
- cpl_frame * rm_crh = NULL ;;
+ cpl_frame * rm_crh = NULL ;
+ cpl_image * sky_map_ima = NULL;
+ cpl_mask * sky_map_msk = NULL;
+ //cpl_frameset_dump(raws,stdout);
 
+ if( sky_map_frm != NULL ) {
+   sky_map_ima = cpl_image_load(cpl_frame_get_filename(sky_map_frm),CPL_TYPE_FLOAT,0,0);
+   sky_map_msk=cpl_mask_threshold_image_create(sky_map_ima,0.1,1.1);
+ }
  sprintf( arm_str, "%s",  xsh_instrument_arm_tostring(instrument) ) ;
  nraws=cpl_frameset_get_size(raws);
  check( clean = cpl_frameset_new() ) ;
@@ -2689,14 +2725,17 @@ xsh_frameset_crh_single(cpl_frameset* raws,xsh_remove_crh_single_param * crh_sin
       sprintf(ftag,"%s_%s_NO_CRH_%s_%d",prefix,spec,arm_str,i) ;
       sprintf(fname,"%s.fits",ftag) ;
 
-      rm_crh = xsh_remove_crh_single( frm,instrument,crh_single_par,ftag ) ;
+      rm_crh = xsh_remove_crh_single( frm,instrument,sky_map_msk,crh_single_par,ftag ) ;
       xsh_add_temporary_file(fname);
       cpl_frameset_insert( clean, rm_crh ) ;
     }
   } else {
     clean=cpl_frameset_duplicate(raws);
   }
-
+ if( sky_map_frm != NULL ) {
+     xsh_free_image(&sky_map_ima);
+     xsh_free_mask(&sky_map_msk);
+ }
 cleanup:
  return clean;
 }
@@ -2753,7 +2792,6 @@ xsh_frameset_mflat_divide(cpl_frameset* input, cpl_frame* mflat,
     xsh_add_temporary_file(fname);
     cpl_frameset_insert(output, divided );
 
-
   }
 
   return output;
