@@ -219,6 +219,7 @@ xsh_slit_stare_get_calibs(cpl_frameset* calib,
                           cpl_frame** model_cfg,
                           cpl_frame** wave_tab,
                           cpl_frame** sky_list,
+                          cpl_frame** sky_orders_chunks,
                           cpl_frame** qc_sky,
                           cpl_frame** bpmap,
                           cpl_frame** sframe_sky_sub_tab,
@@ -280,6 +281,8 @@ xsh_slit_stare_correct_crh_and_sky(xsh_localize_obj_param * loc_obj_par,
                                    xsh_instrument* instrument,
                                    int sub_sky_nbkpts1, 
                                    xsh_subtract_sky_single_param* sky_par,
+                                   cpl_frame* qc_sky_frame,
+                                   cpl_frame* sky_orders_chunks,
                                    cpl_frame** sky,
                                    cpl_frame** sky_eso,
                                    cpl_frame** sky_ima,
@@ -327,7 +330,9 @@ xsh_compute_wavelength_resampling_accuracy(cpl_frame* wavemap,
         cpl_frame* merged1D,
         xsh_instrument* instrument);
 cpl_frameset*
-xsh_frameset_crh_single(cpl_frameset* raws,xsh_remove_crh_single_param * crh_single_par,
+xsh_frameset_crh_single(cpl_frameset* raws,
+                        xsh_remove_crh_single_param * crh_single_par,
+                        cpl_frame* sky_map_frm,
     xsh_instrument* instrument,const char* prefix,const char* spec);
 
 cpl_frameset*
